from setuptools import setup, find_packages

setup(
    name="transprint",
    version="1.4.0",
    py_modules=["transprint"],
    description="Traduce el texto de los prints según el idioma destino",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="Alejo",
    author_email="alejo.duarte.2007@gmail.com",
    url="https://github.com/tuusuario/transprint",
    entry_points={
        "console_scripts": [
            "transprint=transprint:TransPrint.traducir",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
